package javax.swing.text;

import java.awt.Color;
import javax.swing.Icon;
import java.awt.Component;

public class StyleConstants
{
    public static final String ComponentElementName = "component";
    public static final String IconElementName = "icon";
    public static final Object NameAttribute;
    public static final Object ResolveAttribute;
    public static final Object ModelAttribute;
    public static final Object BidiLevel;
    public static final Object FontFamily;
    public static final Object Family;
    public static final Object FontSize;
    public static final Object Size;
    public static final Object Bold;
    public static final Object Italic;
    public static final Object Underline;
    public static final Object StrikeThrough;
    public static final Object Superscript;
    public static final Object Subscript;
    public static final Object Foreground;
    public static final Object Background;
    public static final Object ComponentAttribute;
    public static final Object IconAttribute;
    public static final Object ComposedTextAttribute;
    public static final Object FirstLineIndent;
    public static final Object LeftIndent;
    public static final Object RightIndent;
    public static final Object LineSpacing;
    public static final Object SpaceAbove;
    public static final Object SpaceBelow;
    public static final Object Alignment;
    public static final Object TabSet;
    public static final Object Orientation;
    public static final int ALIGN_LEFT = 0;
    public static final int ALIGN_CENTER = 1;
    public static final int ALIGN_RIGHT = 2;
    public static final int ALIGN_JUSTIFIED = 3;
    static Object[] keys;
    private String representation;
    
    @Override
    public String toString() {
        return this.representation;
    }
    
    public static int getBidiLevel(AttributeSet set) {
        Integer n = (Integer)set.getAttribute(StyleConstants.BidiLevel);
        if (n != null) {
            return (int)n;
        }
        return 0;
    }
    
    public static void setBidiLevel(MutableAttributeSet set, int i) {
        set.addAttribute(StyleConstants.BidiLevel, Integer.valueOf(i));
    }
    
    public static Component getComponent(AttributeSet set) {
        return (Component)set.getAttribute(StyleConstants.ComponentAttribute);
    }
    
    public static void setComponent(MutableAttributeSet set, Component component) {
        set.addAttribute("$ename", "component");
        set.addAttribute(StyleConstants.ComponentAttribute, component);
    }
    
    public static Icon getIcon(AttributeSet set) {
        return (Icon)set.getAttribute(StyleConstants.IconAttribute);
    }
    
    public static void setIcon(MutableAttributeSet set, Icon icon) {
        set.addAttribute("$ename", "icon");
        set.addAttribute(StyleConstants.IconAttribute, icon);
    }
    
    public static String getFontFamily(AttributeSet set) {
        String s = (String)set.getAttribute(StyleConstants.FontFamily);
        if (s == null) {
            s = "Monospaced";
            return s;
        }
        return s;
    }
    
    public static void setFontFamily(MutableAttributeSet set, String s) {
        set.addAttribute(StyleConstants.FontFamily, s);
    }
    
    public static int getFontSize(AttributeSet set) {
        Integer n = (Integer)set.getAttribute(StyleConstants.FontSize);
        if (n != null) {
            return (int)n;
        }
        return 12;
    }
    
    public static void setFontSize(MutableAttributeSet set, int i) {
        set.addAttribute(StyleConstants.FontSize, Integer.valueOf(i));
    }
    
    public static boolean isBold(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.Bold);
        return b != null && (boolean)b;
    }
    
    public static void setBold(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.Bold, Boolean.valueOf(b));
    }
    
    public static boolean isItalic(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.Italic);
        return b != null && (boolean)b;
    }
    
    public static void setItalic(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.Italic, Boolean.valueOf(b));
    }
    
    public static boolean isUnderline(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.Underline);
        return b != null && (boolean)b;
    }
    
    public static boolean isStrikeThrough(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.StrikeThrough);
        return b != null && (boolean)b;
    }
    
    public static boolean isSuperscript(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.Superscript);
        return b != null && (boolean)b;
    }
    
    public static boolean isSubscript(AttributeSet set) {
        Boolean b = (Boolean)set.getAttribute(StyleConstants.Subscript);
        return b != null && (boolean)b;
    }
    
    public static void setUnderline(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.Underline, Boolean.valueOf(b));
    }
    
    public static void setStrikeThrough(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.StrikeThrough, Boolean.valueOf(b));
    }
    
    public static void setSuperscript(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.Superscript, Boolean.valueOf(b));
    }
    
    public static void setSubscript(MutableAttributeSet set, boolean b) {
        set.addAttribute(StyleConstants.Subscript, Boolean.valueOf(b));
    }
    
    public static Color getForeground(AttributeSet set) {
        Color black = (Color)set.getAttribute(StyleConstants.Foreground);
        if (black == null) {
            black = Color.black;
            return black;
        }
        return black;
    }
    
    public static void setForeground(MutableAttributeSet set, Color color) {
        set.addAttribute(StyleConstants.Foreground, color);
    }
    
    public static Color getBackground(AttributeSet set) {
        Color black = (Color)set.getAttribute(StyleConstants.Background);
        if (black == null) {
            black = Color.black;
            return black;
        }
        return black;
    }
    
    public static void setBackground(MutableAttributeSet set, Color color) {
        set.addAttribute(StyleConstants.Background, color);
    }
    
    public static float getFirstLineIndent(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.FirstLineIndent);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setFirstLineIndent(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.FirstLineIndent, new Float(value));
    }
    
    public static float getRightIndent(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.RightIndent);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setRightIndent(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.RightIndent, new Float(value));
    }
    
    public static float getLeftIndent(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.LeftIndent);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setLeftIndent(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.LeftIndent, new Float(value));
    }
    
    public static float getLineSpacing(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.LineSpacing);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setLineSpacing(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.LineSpacing, new Float(value));
    }
    
    public static float getSpaceAbove(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.SpaceAbove);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setSpaceAbove(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.SpaceAbove, new Float(value));
    }
    
    public static float getSpaceBelow(AttributeSet set) {
        Float n = (Float)set.getAttribute(StyleConstants.SpaceBelow);
        if (n != null) {
            return (float)n;
        }
        return 0.0f;
    }
    
    public static void setSpaceBelow(MutableAttributeSet set, float value) {
        set.addAttribute(StyleConstants.SpaceBelow, new Float(value));
    }
    
    public static int getAlignment(AttributeSet set) {
        Integer n = (Integer)set.getAttribute(StyleConstants.Alignment);
        if (n != null) {
            return (int)n;
        }
        return 0;
    }
    
    public static void setAlignment(MutableAttributeSet set, int i) {
        set.addAttribute(StyleConstants.Alignment, Integer.valueOf(i));
    }
    
    public static TabSet getTabSet(AttributeSet set) {
        return (TabSet)set.getAttribute(StyleConstants.TabSet);
    }
    
    public static void setTabSet(MutableAttributeSet set, TabSet set2) {
        set.addAttribute(StyleConstants.TabSet, set2);
    }
    
    StyleConstants(String representation) {
        this.representation = representation;
    }
    
    static {
        NameAttribute = new StyleConstants("name");
        ResolveAttribute = new StyleConstants("resolver");
        ModelAttribute = new StyleConstants("model");
        BidiLevel = new StyleConstants.CharacterConstants("bidiLevel");
        FontFamily = new StyleConstants.FontConstants("family");
        Family = StyleConstants.FontFamily;
        FontSize = new StyleConstants.FontConstants("size");
        Size = StyleConstants.FontSize;
        Bold = new StyleConstants.FontConstants("bold");
        Italic = new StyleConstants.FontConstants("italic");
        Underline = new StyleConstants.CharacterConstants("underline");
        StrikeThrough = new StyleConstants.CharacterConstants("strikethrough");
        Superscript = new StyleConstants.CharacterConstants("superscript");
        Subscript = new StyleConstants.CharacterConstants("subscript");
        Foreground = new StyleConstants.ColorConstants("foreground");
        Background = new StyleConstants.ColorConstants("background");
        ComponentAttribute = new StyleConstants.CharacterConstants("component");
        IconAttribute = new StyleConstants.CharacterConstants("icon");
        ComposedTextAttribute = new StyleConstants("composed text");
        FirstLineIndent = new StyleConstants.ParagraphConstants("FirstLineIndent");
        LeftIndent = new StyleConstants.ParagraphConstants("LeftIndent");
        RightIndent = new StyleConstants.ParagraphConstants("RightIndent");
        LineSpacing = new StyleConstants.ParagraphConstants("LineSpacing");
        SpaceAbove = new StyleConstants.ParagraphConstants("SpaceAbove");
        SpaceBelow = new StyleConstants.ParagraphConstants("SpaceBelow");
        Alignment = new StyleConstants.ParagraphConstants("Alignment");
        TabSet = new StyleConstants.ParagraphConstants("TabSet");
        Orientation = new StyleConstants.ParagraphConstants("Orientation");
        StyleConstants.keys = new Object[] { StyleConstants.NameAttribute, StyleConstants.ResolveAttribute, StyleConstants.BidiLevel, StyleConstants.FontFamily, StyleConstants.FontSize, StyleConstants.Bold, StyleConstants.Italic, StyleConstants.Underline, StyleConstants.StrikeThrough, StyleConstants.Superscript, StyleConstants.Subscript, StyleConstants.Foreground, StyleConstants.Background, StyleConstants.ComponentAttribute, StyleConstants.IconAttribute, StyleConstants.FirstLineIndent, StyleConstants.LeftIndent, StyleConstants.RightIndent, StyleConstants.LineSpacing, StyleConstants.SpaceAbove, StyleConstants.SpaceBelow, StyleConstants.Alignment, StyleConstants.TabSet, StyleConstants.Orientation, StyleConstants.ModelAttribute, StyleConstants.ComposedTextAttribute };
    }
    
    public static class ParagraphConstants extends StyleConstants implements AttributeSet.ParagraphAttribute
    {
        private ParagraphConstants(String s) {
            super(s);
        }
    }
    
    public static class CharacterConstants extends StyleConstants implements AttributeSet.CharacterAttribute
    {
        private CharacterConstants(String s) {
            super(s);
        }
    }
    
    public static class ColorConstants extends StyleConstants implements AttributeSet.ColorAttribute, AttributeSet.CharacterAttribute
    {
        private ColorConstants(String s) {
            super(s);
        }
    }
    
    public static class FontConstants extends StyleConstants implements AttributeSet.FontAttribute, AttributeSet.CharacterAttribute
    {
        private FontConstants(String s) {
            super(s);
        }
    }
}
